@@ -1,3 +1,5 @@
+use crate::CliError;
+use std::fs::write;
 use std::io::{self, Write};
 
 pub fn read_input() -> io::Result<String> {
@@ -19,3 +21,13 @@ pub fn exit(code: ExitCode) {
         ExitCode::Error => std::process::exit(1),
     }
 }
+
+pub fn write_output_to_file(
+    output_file_path: String,
+    compiler_output: String,
+) -> Result<(), CliError> {
+    write(&output_file_path, compiler_output)
+        .map_err(|_| CliError::WriteFileError(output_file_path))?;
+
+    Ok(())
+}
